@@ -33,7 +33,7 @@
 #define HAVE_GEOLOCATION 1
 
 /* Define to 1 if an external Eigen3 shared library have been found */
-/* #undef HAVE_EIGEN3 */
+#define HAVE_EIGEN3 1
 
 /* Define to 1 if an external x265 shared library have been found */
 #define HAVE_X265 1
@@ -42,13 +42,13 @@
 #define HAVE_HEIF 1
 
 /* The Eigen3 version string, if found, or an empty string otherwise */
-#define EIGEN3_VERSION_STRING ".."
+#define EIGEN3_VERSION_STRING "3.4.1"
 
 /* Define to 1 if GPhoto2 shared library is installed */
 #define HAVE_GPHOTO2 1
 
 /* Define to 1 if Jasper shared library is installed */
-#define HAVE_JASPER 1
+/* #undef HAVE_JASPER */
 
 /* Define to 1 if libjxl shared library is installed */
 #define HAVE_JXL 1
@@ -111,3 +111,10 @@
 #define HAVE_IMAGE_MAGICK 1
 
 #define LIBEXEC_INSTALL_DIR "/usr/libexec"
+
+#define CMAKE_VERSION_STRING        "4.1.2"
+#define CMAKE_CXX_COMPILER_ID       "GNU"
+#define CMAKE_CXX_COMPILER_VERSION  "14.2.1"
+#define CMAKE_HOST_PRETTY_NAME      "KaOS (2025)"
+#define CMAKE_SYSTEM_PROCESSOR      "x86_64"
+#define CMAKE_HOST_SYSTEM_PROCESSOR "x86_64"
